@@ -1,10 +1,9 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 
 # test_async.py - unit test for asynchronous API
 #
 # Copyright (C) 2010-2019 Jan Urbański  <wulczer@wulczer.org>
-# Copyright (C) 2020 The Psycopg Team
+# Copyright (C) 2020-2021 The Psycopg Team
 #
 # psycopg2 is free software: you can redistribute it and/or modify it
 # under the terms of the GNU Lesser General Public License as published
@@ -37,7 +36,7 @@ from .testutils import (ConnectingTestCase, StringIO, skip_before_postgres,
     skip_if_crdb, crdb_version, slow)
 
 
-class PollableStub(object):
+class PollableStub:
     """A 'pollable' wrapper allowing analysis of the `poll()` calls."""
     def __init__(self, pollable):
         self.pollable = pollable
@@ -391,6 +390,7 @@ class AsyncTests(ConnectingTestCase):
         # fetching from the correct cursor works
         self.assertEquals(cur1.fetchone()[0], 1)
 
+    @skip_if_crdb("batch statements", version="< 22.1")
     def test_error(self):
         cur = self.conn.cursor()
         cur.execute("insert into table1 values (%s)", (1, ))
@@ -403,9 +403,8 @@ class AsyncTests(ConnectingTestCase):
         # this should fail as well (Postgres behaviour)
         self.assertRaises(psycopg2.IntegrityError, self.wait, cur)
         # but this should work
-        if crdb_version(self.sync_conn) is None:
-            cur.execute("insert into table1 values (%s)", (2, ))
-            self.wait(cur)
+        cur.execute("insert into table1 values (%s)", (2, ))
+        self.wait(cur)
         # and the cursor should be usable afterwards
         cur.execute("insert into table1 values (%s)", (3, ))
         self.wait(cur)
